@@ -1,38 +1,9 @@
-///////////////////////////////////////////////////////////////////////////
-//
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
-//
-// All rights reserved. This software is distributed under the
-// Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
-//
-// Redistributions of source code must retain the above copyright
-// and license notice and the following restrictions and disclaimer.
-//
-// *     Neither the name of DreamWorks Animation nor the names of
-// its contributors may be used to endorse or promote products derived
-// from this software without specific prior written permission.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY INDIRECT, INCIDENTAL,
-// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-// IN NO EVENT SHALL THE COPYRIGHT HOLDERS' AND CONTRIBUTORS' AGGREGATE
-// LIABILITY FOR ALL CLAIMS REGARDLESS OF THEIR BASIS EXCEED US$250.00.
-//
-///////////////////////////////////////////////////////////////////////////
-//
-///////////////////////////////////////////////////////////////////////////
-//
+// Copyright Contributors to the OpenVDB Project
+// SPDX-License-Identifier: MPL-2.0
+
 /// @author Ken Museth
 ///
-/// @file LevelSetAdvect.h
+/// @file tools/LevelSetAdvect.h
 ///
 /// @brief Hyperbolic advection of narrow-band level sets
 
@@ -45,8 +16,9 @@
 #include "LevelSetTracker.h"
 #include "VelocityFields.h" // for EnrightField
 #include <openvdb/math/FiniteDifference.h>
-#include <boost/math/constants/constants.hpp>
 //#include <openvdb/util/CpuTimer.h>
+#include <functional>
+
 
 namespace openvdb {
 OPENVDB_USE_VERSION_NAMESPACE
@@ -84,9 +56,9 @@ namespace tools {
 /// class Interrupter {
 ///   ...
 /// public:
-///   void start(const char* name = NULL)// called when computations begin
-///   void end()                         // called when computations end
-///   bool wasInterrupted(int percent=-1)// return true to break computation
+///   void start(const char* name = nullptr) // called when computations begin
+///   void end()                             // called when computations end
+///   bool wasInterrupted(int percent=-1)    // return true to break computation
 ///};
 /// @endcode
 ///
@@ -101,16 +73,16 @@ template<typename GridT,
 class LevelSetAdvection
 {
 public:
-    typedef GridT                              GridType;
-    typedef LevelSetTracker<GridT, InterruptT> TrackerT;
-    typedef typename TrackerT::LeafRange       LeafRange;
-    typedef typename TrackerT::LeafType        LeafType;
-    typedef typename TrackerT::BufferType      BufferType;
-    typedef typename TrackerT::ValueType       ValueType;
-    typedef typename FieldT::VectorType        VectorType;
+    using GridType = GridT;
+    using TrackerT = LevelSetTracker<GridT, InterruptT>;
+    using LeafRange = typename TrackerT::LeafRange;
+    using LeafType = typename TrackerT::LeafType;
+    using BufferType = typename TrackerT::BufferType;
+    using ValueType = typename TrackerT::ValueType;
+    using VectorType = typename FieldT::VectorType;
 
     /// Main constructor
-    LevelSetAdvection(GridT& grid, const FieldT& field, InterruptT* interrupt = NULL):
+    LevelSetAdvection(GridT& grid, const FieldT& field, InterruptT* interrupt = nullptr):
         mTracker(grid, interrupt), mField(field),
         mSpatialScheme(math::HJWENO5_BIAS),
         mTemporalScheme(math::TVD_RK2) {}
@@ -164,7 +136,7 @@ public:
     size_t advect(ValueType time0, ValueType time1);
 
 private:
-    // disallow copy construction and copy by assinment!
+    // disallow copy construction and copy by assignment!
     LevelSetAdvection(const LevelSetAdvection&);// not implemented
     LevelSetAdvection& operator=(const LevelSetAdvection&);// not implemented
 
@@ -215,7 +187,7 @@ private:
         VectorType*        mVelocity;
         size_t*            mOffsets;
         const MapT*        mMap;
-        typename boost::function<void (Advect*, const LeafRange&)> mTask;
+        typename std::function<void (Advect*, const LeafRange&)> mTask;
         const bool         mIsMaster;
     }; // end of private Advect struct
 
@@ -241,7 +213,7 @@ private:
 
 
 template<typename GridT, typename FieldT, typename InterruptT>
-inline size_t
+size_t
 LevelSetAdvection<GridT, FieldT, InterruptT>::advect(ValueType time0, ValueType time1)
 {
     switch (mSpatialScheme) {
@@ -264,7 +236,7 @@ LevelSetAdvection<GridT, FieldT, InterruptT>::advect(ValueType time0, ValueType
 
 template<typename GridT, typename FieldT, typename InterruptT>
 template<math::BiasedGradientScheme SpatialScheme>
-inline size_t
+size_t
 LevelSetAdvection<GridT, FieldT, InterruptT>::advect1(ValueType time0, ValueType time1)
 {
     switch (mTemporalScheme) {
@@ -283,7 +255,7 @@ LevelSetAdvection<GridT, FieldT, InterruptT>::advect1(ValueType time0, ValueType
 
 template<typename GridT, typename FieldT, typename InterruptT>
 template<math::BiasedGradientScheme SpatialScheme, math::TemporalIntegrationScheme TemporalScheme>
-inline size_t
+size_t
 LevelSetAdvection<GridT, FieldT, InterruptT>::advect2(ValueType time0, ValueType time1)
 {
     const math::Transform& trans = mTracker.grid().transform();
@@ -308,7 +280,7 @@ template<
     math::BiasedGradientScheme SpatialScheme,
     math::TemporalIntegrationScheme TemporalScheme,
     typename MapT>
-inline size_t
+size_t
 LevelSetAdvection<GridT, FieldT, InterruptT>::advect3(ValueType time0, ValueType time1)
 {
     Advect<MapT, SpatialScheme, TemporalScheme> tmp(*this);
@@ -329,8 +301,8 @@ LevelSetAdvection<GridT, FieldT, InterruptT>::
 Advect<MapT, SpatialScheme, TemporalScheme>::
 Advect(LevelSetAdvection& parent)
     : mParent(parent)
-    , mVelocity(NULL)
-    , mOffsets(NULL)
+    , mVelocity(nullptr)
+    , mOffsets(nullptr)
     , mMap(parent.mTracker.grid().transform().template constMap<MapT>().get())
     , mTask(0)
     , mIsMaster(true)
@@ -367,6 +339,8 @@ LevelSetAdvection<GridT, FieldT, InterruptT>::
 Advect<MapT, SpatialScheme, TemporalScheme>::
 advect(ValueType time0, ValueType time1)
 {
+    namespace ph = std::placeholders;
+
     //util::CpuTimer timer;
     size_t countCFL = 0;
     if ( math::isZero(time0 - time1) ) return countCFL;
@@ -385,7 +359,7 @@ advect(ValueType time0, ValueType time1)
         case math::TVD_RK1:
             // Perform one explicit Euler step: t1 = t0 + dt
             // Phi_t1(1) = Phi_t0(0) - dt * VdotG_t0(0)
-            mTask = boost::bind(&Advect::euler01, _1, _2, dt);
+            mTask = std::bind(&Advect::euler01, ph::_1, ph::_2, dt);
 
             // Cook and swap buffer 0 and 1 such that Phi_t1(0) and Phi_t0(1)
             this->cook("Advecting level set using TVD_RK1", 1);
@@ -393,14 +367,14 @@ advect(ValueType time0, ValueType time1)
         case math::TVD_RK2:
             // Perform one explicit Euler step: t1 = t0 + dt
             // Phi_t1(1) = Phi_t0(0) - dt * VdotG_t0(0)
-            mTask = boost::bind(&Advect::euler01, _1, _2, dt);
+            mTask = std::bind(&Advect::euler01, ph::_1, ph::_2, dt);
 
             // Cook and swap buffer 0 and 1 such that Phi_t1(0) and Phi_t0(1)
             this->cook("Advecting level set using TVD_RK1 (step 1 of 2)", 1);
 
             // Convex combine explict Euler step: t2 = t0 + dt
             // Phi_t2(1) = 1/2 * Phi_t0(1) + 1/2 * (Phi_t1(0) - dt * V.Grad_t1(0))
-            mTask = boost::bind(&Advect::euler12, _1, _2, dt);
+            mTask = std::bind(&Advect::euler12, ph::_1, ph::_2, dt);
 
             // Cook and swap buffer 0 and 1 such that Phi_t2(0) and Phi_t1(1)
             this->cook("Advecting level set using TVD_RK1 (step 2 of 2)", 1);
@@ -408,21 +382,21 @@ advect(ValueType time0, ValueType time1)
         case math::TVD_RK3:
             // Perform one explicit Euler step: t1 = t0 + dt
             // Phi_t1(1) = Phi_t0(0) - dt * VdotG_t0(0)
-            mTask = boost::bind(&Advect::euler01, _1, _2, dt);
+            mTask = std::bind(&Advect::euler01, ph::_1, ph::_2, dt);
 
             // Cook and swap buffer 0 and 1 such that Phi_t1(0) and Phi_t0(1)
             this->cook("Advecting level set using TVD_RK3 (step 1 of 3)", 1);
 
             // Convex combine explict Euler step: t2 = t0 + dt/2
             // Phi_t2(2) = 3/4 * Phi_t0(1) + 1/4 * (Phi_t1(0) - dt * V.Grad_t1(0))
-            mTask = boost::bind(&Advect::euler34, _1, _2, dt);
+            mTask = std::bind(&Advect::euler34, ph::_1, ph::_2, dt);
 
             // Cook and swap buffer 0 and 2 such that Phi_t2(0) and Phi_t1(2)
             this->cook("Advecting level set using TVD_RK3 (step 2 of 3)", 2);
 
             // Convex combine explict Euler step: t3 = t0 + dt
             // Phi_t3(2) = 1/3 * Phi_t0(1) + 2/3 * (Phi_t2(0) - dt * V.Grad_t2(0)
-            mTask = boost::bind(&Advect::euler13, _1, _2, dt);
+            mTask = std::bind(&Advect::euler13, ph::_1, ph::_2, dt);
 
             // Cook and swap buffer 0 and 2 such that Phi_t3(0) and Phi_t2(2)
             this->cook("Advecting level set using TVD_RK3 (step 3 of 3)", 2);
@@ -453,6 +427,8 @@ LevelSetAdvection<GridT, FieldT, InterruptT>::
 Advect<MapT, SpatialScheme, TemporalScheme>::
 sampleField(ValueType time0, ValueType time1)
 {
+    namespace ph = std::placeholders;
+
     const int grainSize = mParent.mTracker.getGrainSize();
     const size_t leafCount = mParent.mTracker.leafs().leafCount();
     if (leafCount==0) return ValueType(0.0);
@@ -462,9 +438,9 @@ sampleField(ValueType time0, ValueType time1)
 
     // Sample the velocity field
     if (mParent.mField.transform() == mParent.mTracker.grid().transform()) {
-        mTask = boost::bind(&Advect::sampleAligned, _1, _2, time0, time1);
+        mTask = std::bind(&Advect::sampleAligned, ph::_1, ph::_2, time0, time1);
     } else {
-        mTask = boost::bind(&Advect::sampleXformed, _1, _2, time0, time1);
+        mTask = std::bind(&Advect::sampleXformed, ph::_1, ph::_2, time0, time1);
     }
     assert(voxelCount == mParent.mTracker.grid().activeVoxelCount());
     mVelocity = new VectorType[ voxelCount ];
@@ -479,10 +455,7 @@ sampleField(ValueType time0, ValueType time1)
 
     // Compute the CFL number
     if (math::isApproxZero(maxAbsV, math::Delta<ValueType>::value())) return ValueType(0);
-#ifndef _MSC_VER // Visual C++ doesn't guarantee thread-safe initialization of local statics
-    static
-#endif
-    const ValueType CFL = (TemporalScheme == math::TVD_RK1 ? ValueType(0.3) :
+    static const ValueType CFL = (TemporalScheme == math::TVD_RK1 ? ValueType(0.3) :
         TemporalScheme == math::TVD_RK2 ? ValueType(0.9) :
         ValueType(1.0))/math::Sqrt(ValueType(3.0));
     const ValueType dt = math::Abs(time1 - time0), dx = mParent.mTracker.voxelSize();
@@ -502,16 +475,18 @@ Advect<MapT, SpatialScheme, TemporalScheme>::
 sample(const LeafRange& range, ValueType time0, ValueType time1)
 {
     const bool isForward = time0 < time1;
-    typedef typename LeafType::ValueOnCIter VoxelIterT;
+    using VoxelIterT = typename LeafType::ValueOnCIter;
     const MapT& map = *mMap;
     const FieldT field( mParent.mField );
     mParent.mTracker.checkInterrupter();
     for (typename LeafRange::Iterator leafIter = range.begin(); leafIter; ++leafIter) {
         VectorType* vel = mVelocity + mOffsets[ leafIter.pos() ];
         for (VoxelIterT iter = leafIter->cbeginValueOn(); iter; ++iter, ++vel) {
+            OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN
             const VectorType v = Aligned ? field(iter.getCoord(), time0) ://resolved at compile time
                                  field(map.applyMap(iter.getCoord().asVec3d()), time0);
             *vel = isForward ? v : -v;
+            OPENVDB_NO_TYPE_CONVERSION_WARNING_END
         }
     }
 }
@@ -529,8 +504,8 @@ clearField()
 {
     delete [] mOffsets;
     delete [] mVelocity;
-    mOffsets  = NULL;
-    mVelocity = NULL;
+    mOffsets = nullptr;
+    mVelocity = nullptr;
 }
 
 
@@ -570,10 +545,10 @@ LevelSetAdvection<GridT, FieldT, InterruptT>::
 Advect<MapT, SpatialScheme, TemporalScheme>::
 euler(const LeafRange& range, ValueType dt, Index phiBuffer, Index resultBuffer)
 {
-    typedef math::BIAS_SCHEME<SpatialScheme>                             SchemeT;
-    typedef typename SchemeT::template ISStencil<GridType>::StencilType  StencilT;
-    typedef typename LeafType::ValueOnCIter                              VoxelIterT;
-    typedef math::GradientBiased<MapT, SpatialScheme>                    GradT;
+    using SchemeT = math::BIAS_SCHEME<SpatialScheme>;
+    using StencilT = typename SchemeT::template ISStencil<GridType>::StencilType;
+    using VoxelIterT = typename LeafType::ValueOnCIter;
+    using GradT = math::GradientBiased<MapT, SpatialScheme>;
 
     static const ValueType Alpha = ValueType(Nominator)/ValueType(Denominator);
     static const ValueType Beta  = ValueType(1) - Alpha;
@@ -595,12 +570,26 @@ euler(const LeafRange& range, ValueType dt, Index phiBuffer, Index resultBuffer)
     }//loop over leafs of the level set
 }
 
+
+////////////////////////////////////////
+
+
+// Explicit Template Instantiation
+
+#ifdef OPENVDB_USE_EXPLICIT_INSTANTIATION
+
+#ifdef OPENVDB_INSTANTIATE_LEVELSETADVECT
+#include <openvdb/util/ExplicitInstantiation.h>
+#endif
+
+OPENVDB_INSTANTIATE_CLASS LevelSetAdvection<FloatGrid, DiscreteField<Vec3SGrid, BoxSampler>, util::NullInterrupter>;
+OPENVDB_INSTANTIATE_CLASS LevelSetAdvection<DoubleGrid, DiscreteField<Vec3SGrid, BoxSampler>, util::NullInterrupter>;
+
+#endif // OPENVDB_USE_EXPLICIT_INSTANTIATION
+
+
 } // namespace tools
 } // namespace OPENVDB_VERSION_NAME
 } // namespace openvdb
 
 #endif // OPENVDB_TOOLS_LEVEL_SET_ADVECT_HAS_BEEN_INCLUDED
-
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
-// All rights reserved. This software is distributed under the
-// Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
