@@ -1,32 +1,5 @@
-///////////////////////////////////////////////////////////////////////////
-//
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
-//
-// All rights reserved. This software is distributed under the
-// Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
-//
-// Redistributions of source code must retain the above copyright
-// and license notice and the following restrictions and disclaimer.
-//
-// *     Neither the name of DreamWorks Animation nor the names of
-// its contributors may be used to endorse or promote products derived
-// from this software without specific prior written permission.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY INDIRECT, INCIDENTAL,
-// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-// IN NO EVENT SHALL THE COPYRIGHT HOLDERS' AND CONTRIBUTORS' AGGREGATE
-// LIABILITY FOR ALL CLAIMS REGARDLESS OF THEIR BASIS EXCEED US$250.00.
-//
-///////////////////////////////////////////////////////////////////////////
+// Copyright Contributors to the OpenVDB Project
+// SPDX-License-Identifier: MPL-2.0
 
 #ifndef OPENVDB_TREE_LEAFNODE_HAS_BEEN_INCLUDED
 #define OPENVDB_TREE_LEAFNODE_HAS_BEEN_INCLUDED
@@ -36,10 +9,13 @@
 #include <openvdb/io/Compression.h> // for io::readData(), etc.
 #include "Iterator.h"
 #include "LeafBuffer.h"
+#include <algorithm> // for std::nth_element()
 #include <iostream>
 #include <memory>
-#include <algorithm>// for std::nth_element
+#include <sstream>
+#include <string>
 #include <type_traits>
+#include <vector>
 
 
 class TestLeaf;
@@ -101,8 +77,6 @@ public:
                       const ValueType& value = zeroVal<ValueType>(),
                       bool active = false);
 
-
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     /// @brief "Partial creation" constructor used during file input
     /// @param coords  the grid index coordinates of a voxel
     /// @param value   a value with which to fill the buffer
@@ -112,7 +86,6 @@ public:
              const Coord& coords,
              const ValueType& value = zeroVal<ValueType>(),
              bool active = false);
-#endif
 
     /// Deep copy constructor
     LeafNode(const LeafNode&);
@@ -156,8 +129,12 @@ public:
     static Index getChildDim() { return 1; }
     /// Return the leaf count for this node, which is one.
     static Index32 leafCount() { return 1; }
+    /// no-op
+    void nodeCount(std::vector<Index32> &) const {}
     /// Return the non-leaf count for this node, which is zero.
     static Index32 nonLeafCount() { return 0; }
+    /// Return the child count for this node, which is zero.
+    static Index32 childCount() { return 0; }
 
     /// Return the number of voxels marked On.
     Index64 onVoxelCount() const { return mValueMask.countOn(); }
@@ -171,13 +148,10 @@ public:
     bool isEmpty() const { return mValueMask.isOff(); }
     /// Return @c true if this node contains only active voxels.
     bool isDense() const { return mValueMask.isOn(); }
-
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     /// Return @c true if memory for this node's buffer has been allocated.
     bool isAllocated() const { return !mBuffer.isOutOfCore() && !mBuffer.empty(); }
     /// Allocate memory for this node's buffer if it has not already been allocated.
     bool allocate() { return mBuffer.allocate(); }
-#endif
 
     /// Return the memory in bytes occupied by this node.
     Index64 memUsage() const;
@@ -208,6 +182,13 @@ public:
     /// Return the global coordinates for a linear table offset.
     Coord offsetToGlobalCoord(Index n) const;
 
+#if OPENVDB_ABI_VERSION_NUMBER >= 9
+    /// Return the transient data value.
+    Index32 transientData() const { return mTransientData; }
+    /// Set the transient data value.
+    void setTransientData(Index32 transientData) { mTransientData = transientData; }
+#endif
+
     /// Return a string representation of this node.
     std::string str() const;
 
@@ -454,11 +435,15 @@ public:
     template<typename ModifyOp>
     void modifyValue(Index offset, const ModifyOp& op)
     {
-        ValueType val = mBuffer[offset];
-        op(val);
-        mBuffer.setValue(offset, val);
-        mValueMask.setOn(offset);
+        mBuffer.loadValues();
+        if (!mBuffer.empty()) {
+            // in-place modify value
+            ValueType& val = const_cast<ValueType&>(mBuffer[offset]);
+            op(val);
+            mValueMask.setOn(offset);
+        }
     }
+
     /// @brief Apply a functor to the value of the voxel at the given coordinates
     /// and mark the voxel as active.
     template<typename ModifyOp>
@@ -471,12 +456,15 @@ public:
     template<typename ModifyOp>
     void modifyValueAndActiveState(const Coord& xyz, const ModifyOp& op)
     {
-        const Index offset = this->coordToOffset(xyz);
-        bool state = mValueMask.isOn(offset);
-        ValueType val = mBuffer[offset];
-        op(val, state);
-        mBuffer.setValue(offset, val);
-        mValueMask.set(offset, state);
+        mBuffer.loadValues();
+        if (!mBuffer.empty()) {
+            const Index offset = this->coordToOffset(xyz);
+            bool state = mValueMask.isOn(offset);
+            // in-place modify value
+            ValueType& val = const_cast<ValueType&>(mBuffer[offset]);
+            op(val, state);
+            mValueMask.set(offset, state);
+        }
     }
 
     /// Mark all voxels as active but don't change their values.
@@ -661,7 +649,7 @@ public:
     ///
     /// @note This operation modifies only active states, not values.
     template<typename OtherType>
-    void topologyUnion(const LeafNode<OtherType, Log2Dim>& other);
+    void topologyUnion(const LeafNode<OtherType, Log2Dim>& other, const bool preserveTiles = false);
 
     /// @brief Intersect this node's set of active values with the active values
     /// of the other node, whose @c ValueType may be different. So a
@@ -673,7 +661,7 @@ public:
     ///
     /// @note This operation modifies only active states, not
     /// values. Also note that this operation can result in all voxels
-    /// being inactive so consider subsequnetly calling prune.
+    /// being inactive so consider subsequently calling prune.
     template<typename OtherType>
     void topologyIntersection(const LeafNode<OtherType, Log2Dim>& other, const ValueType&);
 
@@ -707,7 +695,7 @@ public:
     /// information. An additional level argument is provided to the
     /// callback.
     ///
-    /// @note The bounding boxes are guarenteed to be non-overlapping.
+    /// @note The bounding boxes are guaranteed to be non-overlapping.
     template<typename BBoxOp> void visitActiveBBox(BBoxOp&) const;
 
     template<typename VisitorOp> void visit(VisitorOp&);
@@ -786,7 +774,7 @@ public:
     /// @param state       Is updated with the state of all values IF method
     ///                    returns @c true. Else the value is undefined!
     /// @param tolerance   The tolerance used to determine if values are
-    ///                    approximatly equal to the for value.
+    ///                    approximately equal to the for value.
     bool isConstant(ValueType& firstValue, bool& state,
                     const ValueType& tolerance = zeroVal<ValueType>()) const;
 
@@ -800,7 +788,7 @@ public:
     /// @param state     Is updated with the state of all values IF method
     ///                  returns @c true. Else the value is undefined!
     /// @param tolerance The tolerance used to determine if values are
-    ///                  approximatly constant.
+    ///                  approximately constant.
     bool isConstant(ValueType& minValue, ValueType& maxValue,
                     bool& state, const ValueType& tolerance = zeroVal<ValueType>()) const;
 
@@ -814,7 +802,7 @@ public:
     ///
     /// @note If tmp = this->buffer().data() then the median
     ///       value is computed very efficiently (in place) but
-    ///       the voxel values in this node are re-shuffeled!
+    ///       the voxel values in this node are re-shuffled!
     ///
     /// @warning If tmp != nullptr then it is the responsibility of
     ///          the client code that it points to enough memory to
@@ -918,6 +906,10 @@ private:
     NodeMaskType mValueMask;
     /// Global grid index coordinates (x,y,z) of the local origin of this node
     Coord mOrigin;
+#if OPENVDB_ABI_VERSION_NUMBER >= 9
+    /// Transient data (not serialized)
+    Index32 mTransientData = 0;
+#endif
 }; // end of LeafNode class
 
 
@@ -957,7 +949,6 @@ LeafNode<T, Log2Dim>::LeafNode(const Coord& xyz, const ValueType& val, bool acti
 }
 
 
-#ifndef OPENVDB_2_ABI_COMPATIBLE
 template<typename T, Index Log2Dim>
 inline
 LeafNode<T, Log2Dim>::LeafNode(PartialCreate, const Coord& xyz, const ValueType& val, bool active):
@@ -966,15 +957,17 @@ LeafNode<T, Log2Dim>::LeafNode(PartialCreate, const Coord& xyz, const ValueType&
     mOrigin(xyz & (~(DIM - 1)))
 {
 }
-#endif
 
 
 template<typename T, Index Log2Dim>
 inline
-LeafNode<T, Log2Dim>::LeafNode(const LeafNode& other):
-    mBuffer(other.mBuffer),
-    mValueMask(other.valueMask()),
-    mOrigin(other.mOrigin)
+LeafNode<T, Log2Dim>::LeafNode(const LeafNode& other)
+    : mBuffer(other.mBuffer)
+    , mValueMask(other.valueMask())
+    , mOrigin(other.mOrigin)
+#if OPENVDB_ABI_VERSION_NUMBER >= 9
+    , mTransientData(other.mTransientData)
+#endif
 {
 }
 
@@ -983,9 +976,12 @@ LeafNode<T, Log2Dim>::LeafNode(const LeafNode& other):
 template<typename T, Index Log2Dim>
 template<typename OtherValueType>
 inline
-LeafNode<T, Log2Dim>::LeafNode(const LeafNode<OtherValueType, Log2Dim>& other):
-    mValueMask(other.valueMask()),
-    mOrigin(other.mOrigin)
+LeafNode<T, Log2Dim>::LeafNode(const LeafNode<OtherValueType, Log2Dim>& other)
+    : mValueMask(other.valueMask())
+    , mOrigin(other.mOrigin)
+#if OPENVDB_ABI_VERSION_NUMBER >= 9
+    , mTransientData(other.mTransientData)
+#endif
 {
     struct Local {
         /// @todo Consider using a value conversion functor passed as an argument instead.
@@ -1002,10 +998,13 @@ template<typename T, Index Log2Dim>
 template<typename OtherValueType>
 inline
 LeafNode<T, Log2Dim>::LeafNode(const LeafNode<OtherValueType, Log2Dim>& other,
-                               const ValueType& background, TopologyCopy):
-    mBuffer(background),
-    mValueMask(other.valueMask()),
-    mOrigin(other.mOrigin)
+                               const ValueType& background, TopologyCopy)
+    : mBuffer(background)
+    , mValueMask(other.valueMask())
+    , mOrigin(other.mOrigin)
+#if OPENVDB_ABI_VERSION_NUMBER >= 9
+    , mTransientData(other.mTransientData)
+#endif
 {
 }
 
@@ -1014,9 +1013,12 @@ template<typename T, Index Log2Dim>
 template<typename OtherValueType>
 inline
 LeafNode<T, Log2Dim>::LeafNode(const LeafNode<OtherValueType, Log2Dim>& other,
-    const ValueType& offValue, const ValueType& onValue, TopologyCopy):
-    mValueMask(other.valueMask()),
-    mOrigin(other.mOrigin)
+    const ValueType& offValue, const ValueType& onValue, TopologyCopy)
+    : mValueMask(other.valueMask())
+    , mOrigin(other.mOrigin)
+#if OPENVDB_ABI_VERSION_NUMBER >= 9
+    , mTransientData(other.mTransientData)
+#endif
 {
     for (Index i = 0; i < SIZE; ++i) {
         mBuffer[i] = (mValueMask.isOn(i) ? onValue : offValue);
@@ -1199,9 +1201,7 @@ template<typename T, Index Log2Dim>
 inline void
 LeafNode<T, Log2Dim>::fill(const CoordBBox& bbox, const ValueType& value, bool active)
 {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     if (!this->allocate()) return;
-#endif
 
     auto clippedBBox = this->getNodeBoundingBox();
     clippedBBox.intersect(bbox);
@@ -1244,9 +1244,7 @@ template<typename DenseT>
 inline void
 LeafNode<T, Log2Dim>::copyToDense(const CoordBBox& bbox, DenseT& dense) const
 {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     mBuffer.loadValues();
-#endif
 
     using DenseValueType = typename DenseT::ValueType;
 
@@ -1274,9 +1272,7 @@ inline void
 LeafNode<T, Log2Dim>::copyFromDense(const CoordBBox& bbox, const DenseT& dense,
                                     const ValueType& background, const ValueType& tolerance)
 {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     if (!this->allocate()) return;
-#endif
 
     using DenseValueType = typename DenseT::ValueType;
 
@@ -1359,9 +1355,7 @@ LeafNode<T,Log2Dim>::readBuffers(std::istream& is, const CoordBBox& clipBBox, bo
     SharedPtr<io::StreamMetadata> meta = io::getStreamMetadataPtr(is);
     const bool seekable = meta && meta->seekable();
 
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     std::streamoff maskpos = is.tellg();
-#endif
 
     if (seekable) {
         // Seek over the value mask.
@@ -1387,7 +1381,6 @@ LeafNode<T,Log2Dim>::readBuffers(std::istream& is, const CoordBBox& clipBBox, bo
         mValueMask.setOff();
         mBuffer.setOutOfCore(false);
     } else {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
         // If this node lies completely inside the clipping region and it is being read
         // from a memory-mapped file, delay loading of its buffer until the buffer
         // is actually accessed.  (If this node requires clipping, its buffer
@@ -1407,7 +1400,6 @@ LeafNode<T,Log2Dim>::readBuffers(std::istream& is, const CoordBBox& clipBBox, bo
             // Skip over voxel values.
             skipCompressedValues(seekable, is, fromHalf);
         } else {
-#endif
             mBuffer.allocate();
             io::readCompressedValues(is, mBuffer.mData, SIZE, mValueMask, fromHalf);
             mBuffer.setOutOfCore(false);
@@ -1418,9 +1410,7 @@ LeafNode<T,Log2Dim>::readBuffers(std::istream& is, const CoordBBox& clipBBox, bo
                 background = *static_cast<const T*>(bgPtr);
             }
             this->clip(clipBBox, background);
-#ifndef OPENVDB_2_ABI_COMPATIBLE
         }
-#endif
     }
 
     if (numBuffers > 1) {
@@ -1436,6 +1426,9 @@ LeafNode<T,Log2Dim>::readBuffers(std::istream& is, const CoordBBox& clipBBox, bo
             }
         }
     }
+
+    // increment the leaf number
+    if (meta)   meta->setLeaf(meta->leaf() + 1);
 }
 
 
@@ -1641,9 +1634,7 @@ inline void
 LeafNode<T, Log2Dim>::resetBackground(const ValueType& oldBackground,
                                       const ValueType& newBackground)
 {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     if (!this->allocate()) return;
-#endif
 
     typename NodeMaskType::OffIterator iter;
     // For all inactive values...
@@ -1663,9 +1654,7 @@ template<MergePolicy Policy>
 inline void
 LeafNode<T, Log2Dim>::merge(const LeafNode& other)
 {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     if (!this->allocate()) return;
-#endif
 
     OPENVDB_NO_UNREACHABLE_CODE_WARNING_BEGIN
     if (Policy == MERGE_NODES) return;
@@ -1694,9 +1683,7 @@ template<MergePolicy Policy>
 inline void
 LeafNode<T, Log2Dim>::merge(const ValueType& tileValue, bool tileActive)
 {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     if (!this->allocate()) return;
-#endif
 
     OPENVDB_NO_UNREACHABLE_CODE_WARNING_BEGIN
     if (Policy != MERGE_ACTIVE_STATES_AND_NODES) return;
@@ -1714,7 +1701,7 @@ LeafNode<T, Log2Dim>::merge(const ValueType& tileValue, bool tileActive)
 template<typename T, Index Log2Dim>
 template<typename OtherType>
 inline void
-LeafNode<T, Log2Dim>::topologyUnion(const LeafNode<OtherType, Log2Dim>& other)
+LeafNode<T, Log2Dim>::topologyUnion(const LeafNode<OtherType, Log2Dim>& other, bool)
 {
     mValueMask |= other.valueMask();
 }
@@ -1741,9 +1728,8 @@ template<typename T, Index Log2Dim>
 inline void
 LeafNode<T, Log2Dim>::negate()
 {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     if (!this->allocate()) return;
-#endif
+
     for (Index i = 0; i < SIZE; ++i) {
         mBuffer[i] = -mBuffer[i];
     }
@@ -1758,9 +1744,8 @@ template<typename CombineOp>
 inline void
 LeafNode<T, Log2Dim>::combine(const LeafNode& other, CombineOp& op)
 {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     if (!this->allocate()) return;
-#endif
+
     CombineArgs<T> args;
     for (Index i = 0; i < SIZE; ++i) {
         op(args.setARef(mBuffer[i])
@@ -1778,9 +1763,8 @@ template<typename CombineOp>
 inline void
 LeafNode<T, Log2Dim>::combine(const ValueType& value, bool valueIsActive, CombineOp& op)
 {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     if (!this->allocate()) return;
-#endif
+
     CombineArgs<T> args;
     args.setBRef(value).setBIsActive(valueIsActive);
     for (Index i = 0; i < SIZE; ++i) {
@@ -1801,9 +1785,8 @@ inline void
 LeafNode<T, Log2Dim>::combine2(const LeafNode& other, const OtherType& value,
     bool valueIsActive, CombineOp& op)
 {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     if (!this->allocate()) return;
-#endif
+
     CombineArgs<T, OtherType> args;
     args.setBRef(value).setBIsActive(valueIsActive);
     for (Index i = 0; i < SIZE; ++i) {
@@ -1821,9 +1804,8 @@ inline void
 LeafNode<T, Log2Dim>::combine2(const ValueType& value, const OtherNodeT& other,
     bool valueIsActive, CombineOp& op)
 {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     if (!this->allocate()) return;
-#endif
+
     CombineArgs<T, typename OtherNodeT::ValueType> args;
     args.setARef(value).setAIsActive(valueIsActive);
     for (Index i = 0; i < SIZE; ++i) {
@@ -1840,9 +1822,8 @@ template<typename CombineOp, typename OtherNodeT>
 inline void
 LeafNode<T, Log2Dim>::combine2(const LeafNode& b0, const OtherNodeT& b1, CombineOp& op)
 {
-#ifndef OPENVDB_2_ABI_COMPATIBLE
     if (!this->allocate()) return;
-#endif
+
     CombineArgs<T, typename OtherNodeT::ValueType> args;
     for (Index i = 0; i < SIZE; ++i) {
         mValueMask.set(i, b0.valueMask().isOn(i) || b1.valueMask().isOn(i));
@@ -1866,18 +1847,10 @@ LeafNode<T, Log2Dim>::visitActiveBBox(BBoxOp& op) const
 {
     if (op.template descent<LEVEL>()) {
         for (ValueOnCIter i=this->cbeginValueOn(); i; ++i) {
-#ifdef _MSC_VER
-            op.operator()<LEVEL>(CoordBBox::createCube(i.getCoord(), 1));
-#else
             op.template operator()<LEVEL>(CoordBBox::createCube(i.getCoord(), 1));
-#endif
         }
     } else {
-#ifdef _MSC_VER
-        op.operator()<LEVEL>(this->getNodeBoundingBox());
-#else
         op.template operator()<LEVEL>(this->getNodeBoundingBox());
-#endif
     }
 }
 
@@ -2032,7 +2005,3 @@ operator<<(std::ostream& os, const typename LeafNode<T, Log2Dim>::Buffer& buf)
 #include "LeafNodeMask.h"
 
 #endif // OPENVDB_TREE_LEAFNODE_HAS_BEEN_INCLUDED
-
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
-// All rights reserved. This software is distributed under the
-// Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
