@@ -75,23 +75,28 @@ var searchData=
   ['isstencil_72',['ISStencil',['../structopenvdb_1_1v9__0_1_1math_1_1BIAS__SCHEME_1_1ISStencil.html',1,'BIAS_SCHEME&lt; bgs &gt;::ISStencil&lt; GridType, IsSafe &gt;'],['../structopenvdb_1_1v9__0_1_1math_1_1BIAS__SCHEME_3_01FIRST__BIAS_01_4_1_1ISStencil.html',1,'BIAS_SCHEME&lt; FIRST_BIAS &gt;::ISStencil'],['../structopenvdb_1_1v9__0_1_1math_1_1BIAS__SCHEME_3_01HJWENO5__BIAS_01_4_1_1ISStencil.html',1,'BIAS_SCHEME&lt; HJWENO5_BIAS &gt;::ISStencil'],['../structopenvdb_1_1v9__0_1_1math_1_1BIAS__SCHEME_3_01SECOND__BIAS_01_4_1_1ISStencil.html',1,'BIAS_SCHEME&lt; SECOND_BIAS &gt;::ISStencil'],['../structopenvdb_1_1v9__0_1_1math_1_1BIAS__SCHEME_3_01THIRD__BIAS_01_4_1_1ISStencil.html',1,'BIAS_SCHEME&lt; THIRD_BIAS &gt;::ISStencil'],['../structopenvdb_1_1v9__0_1_1math_1_1BIAS__SCHEME_3_01WENO5__BIAS_01_4_1_1ISStencil.html',1,'BIAS_SCHEME&lt; WENO5_BIAS &gt;::ISStencil']]],
   ['iterator_73',['Iterator',['../classnanovdb_1_1BBox_3_01CoordT_00_01false_01_4_1_1Iterator.html',1,'BBox&lt; CoordT, false &gt;::Iterator'],['../classnanovdb_1_1Mask_1_1Iterator.html',1,'Mask&lt; LOG2DIM &gt;::Iterator'],['../classopenvdb_1_1v9__0_1_1math_1_1CoordBBox_1_1Iterator.html',1,'CoordBBox::Iterator&lt; ZYXOrder &gt;'],['../structopenvdb_1_1v9__0_1_1tools_1_1ParticleAtlas_1_1Iterator.html',1,'ParticleAtlas&lt; PointIndexGridType &gt;::Iterator'],['../classopenvdb_1_1v9__0_1_1tree_1_1LeafManager_1_1LeafRange_1_1Iterator.html',1,'LeafManager&lt; TreeT &gt;::LeafRange::Iterator'],['../classopenvdb_1_1v9__0_1_1tree_1_1NodeList_1_1NodeRange_1_1Iterator.html',1,'NodeList&lt; NodeT &gt;::NodeRange::Iterator'],['../classopenvdb_1_1v9__0_1_1util_1_1PagedArray_1_1Iterator.html',1,'PagedArray&lt; ValueT, Log2PageSize &gt;::Iterator']]],
   ['iteratorbase_74',['IteratorBase',['../classopenvdb_1_1v9__0_1_1tree_1_1IteratorBase.html',1,'openvdb::v9_0::tree']]],
-  ['iteratorrange_75',['IteratorRange',['../classopenvdb_1_1v9__0_1_1tree_1_1IteratorRange.html',1,'openvdb::v9_0::tree']]],
-  ['iterlistitem_76',['IterListItem',['../classopenvdb_1_1v9__0_1_1tree_1_1IterListItem.html',1,'openvdb::v9_0::tree']]],
-  ['iterlistitem_3c_20iterlistitem_2c_20restt_2c_20vecsize_20_2d_201_2c_201_20_3e_77',['IterListItem&lt; IterListItem, RestT, VecSize - 1, 1 &gt;',['../classopenvdb_1_1v9__0_1_1tree_1_1IterListItem.html',1,'openvdb::v9_0::tree']]],
-  ['iterlistitem_3c_20previtemt_2c_20nodevect_2c_201_2c_20_5flevel_20_3e_78',['IterListItem&lt; PrevItemT, NodeVecT, 1, _Level &gt;',['../classopenvdb_1_1v9__0_1_1tree_1_1IterListItem_3_01PrevItemT_00_01NodeVecT_00_011_00_01__Level_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['iterlistitem_3c_20previtemt_2c_20nodevect_2c_20vecsize_2c_200u_20_3e_79',['IterListItem&lt; PrevItemT, NodeVecT, VecSize, 0U &gt;',['../classopenvdb_1_1v9__0_1_1tree_1_1IterListItem_3_01PrevItemT_00_01NodeVecT_00_01VecSize_00_010U_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_80',['IterTraits',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3achildallciter_20_3e_81',['IterTraits&lt; NodeT, typename NodeT::ChildAllCIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ChildAllCIter_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3achildalliter_20_3e_82',['IterTraits&lt; NodeT, typename NodeT::ChildAllIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ChildAllIter_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3achildoffciter_20_3e_83',['IterTraits&lt; NodeT, typename NodeT::ChildOffCIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ChildOffCIter_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3achildoffiter_20_3e_84',['IterTraits&lt; NodeT, typename NodeT::ChildOffIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ChildOffIter_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3achildonciter_20_3e_85',['IterTraits&lt; NodeT, typename NodeT::ChildOnCIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ChildOnCIter_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3achildoniter_20_3e_86',['IterTraits&lt; NodeT, typename NodeT::ChildOnIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ChildOnIter_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3avalueallciter_20_3e_87',['IterTraits&lt; NodeT, typename NodeT::ValueAllCIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ValueAllCIter_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3avaluealliter_20_3e_88',['IterTraits&lt; NodeT, typename NodeT::ValueAllIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ValueAllIter_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3avalueoffciter_20_3e_89',['IterTraits&lt; NodeT, typename NodeT::ValueOffCIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ValueOffCIter_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3avalueoffiter_20_3e_90',['IterTraits&lt; NodeT, typename NodeT::ValueOffIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ValueOffIter_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3avalueonciter_20_3e_91',['IterTraits&lt; NodeT, typename NodeT::ValueOnCIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ValueOnCIter_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3avalueoniter_20_3e_92',['IterTraits&lt; NodeT, typename NodeT::ValueOnIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ValueOnIter_01_4.html',1,'openvdb::v9_0::tree']]],
-  ['itertraits_3c_20typename_20previtert_3a_3anonconstnodetype_2c_20previtert_20_3e_93',['IterTraits&lt; typename PrevIterT::NonConstNodeType, PrevIterT &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits.html',1,'openvdb::v9_0::tree']]]
+  ['iteratorbase_3c_20maskdenseiter_2c_20nodet_20_3e_75',['IteratorBase&lt; MaskDenseIter, NodeT &gt;',['../classopenvdb_1_1v9__0_1_1tree_1_1IteratorBase.html',1,'openvdb::v9_0::tree']]],
+  ['iteratorbase_3c_20maskdenseiterator_2c_20nodet_20_3e_76',['IteratorBase&lt; MaskDenseIterator, NodeT &gt;',['../classopenvdb_1_1v9__0_1_1tree_1_1IteratorBase.html',1,'openvdb::v9_0::tree']]],
+  ['iteratorrange_77',['IteratorRange',['../classopenvdb_1_1v9__0_1_1tree_1_1IteratorRange.html',1,'openvdb::v9_0::tree']]],
+  ['iterlistitem_78',['IterListItem',['../classopenvdb_1_1v9__0_1_1tree_1_1IterListItem.html',1,'openvdb::v9_0::tree']]],
+  ['iterlistitem_3c_20iterlistitem_2c_20restt_2c_20vecsize_20_2d_201_2c_201_20_3e_79',['IterListItem&lt; IterListItem, RestT, VecSize - 1, 1 &gt;',['../classopenvdb_1_1v9__0_1_1tree_1_1IterListItem.html',1,'openvdb::v9_0::tree']]],
+  ['iterlistitem_3c_20prevchilditem_2c_20invtreet_2c_20root_5flevel_2b1_2c_200_20_3e_80',['IterListItem&lt; PrevChildItem, InvTreeT, ROOT_LEVEL+1, 0 &gt;',['../classopenvdb_1_1v9__0_1_1tree_1_1IterListItem.html',1,'openvdb::v9_0::tree']]],
+  ['iterlistitem_3c_20previtem_2c_20invtreet_2c_20root_5flevel_2b1_2c_20leaf_5flevel_20_3e_81',['IterListItem&lt; PrevItem, InvTreeT, ROOT_LEVEL+1, LEAF_LEVEL &gt;',['../classopenvdb_1_1v9__0_1_1tree_1_1IterListItem.html',1,'openvdb::v9_0::tree']]],
+  ['iterlistitem_3c_20previtemt_2c_20nodevect_2c_201_2c_20_5flevel_20_3e_82',['IterListItem&lt; PrevItemT, NodeVecT, 1, _Level &gt;',['../classopenvdb_1_1v9__0_1_1tree_1_1IterListItem_3_01PrevItemT_00_01NodeVecT_00_011_00_01__Level_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['iterlistitem_3c_20previtemt_2c_20nodevect_2c_20vecsize_2c_200u_20_3e_83',['IterListItem&lt; PrevItemT, NodeVecT, VecSize, 0U &gt;',['../classopenvdb_1_1v9__0_1_1tree_1_1IterListItem_3_01PrevItemT_00_01NodeVecT_00_01VecSize_00_010U_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['iterlistitem_3c_20prevvalueitem_2c_20invtreet_2c_20root_5flevel_2b1_2c_200_20_3e_84',['IterListItem&lt; PrevValueItem, InvTreeT, ROOT_LEVEL+1, 0 &gt;',['../classopenvdb_1_1v9__0_1_1tree_1_1IterListItem.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_85',['IterTraits',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3achildallciter_20_3e_86',['IterTraits&lt; NodeT, typename NodeT::ChildAllCIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ChildAllCIter_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3achildalliter_20_3e_87',['IterTraits&lt; NodeT, typename NodeT::ChildAllIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ChildAllIter_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3achildoffciter_20_3e_88',['IterTraits&lt; NodeT, typename NodeT::ChildOffCIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ChildOffCIter_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3achildoffiter_20_3e_89',['IterTraits&lt; NodeT, typename NodeT::ChildOffIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ChildOffIter_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3achildonciter_20_3e_90',['IterTraits&lt; NodeT, typename NodeT::ChildOnCIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ChildOnCIter_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3achildoniter_20_3e_91',['IterTraits&lt; NodeT, typename NodeT::ChildOnIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ChildOnIter_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3avalueallciter_20_3e_92',['IterTraits&lt; NodeT, typename NodeT::ValueAllCIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ValueAllCIter_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3avaluealliter_20_3e_93',['IterTraits&lt; NodeT, typename NodeT::ValueAllIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ValueAllIter_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3avalueoffciter_20_3e_94',['IterTraits&lt; NodeT, typename NodeT::ValueOffCIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ValueOffCIter_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3avalueoffiter_20_3e_95',['IterTraits&lt; NodeT, typename NodeT::ValueOffIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ValueOffIter_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3avalueonciter_20_3e_96',['IterTraits&lt; NodeT, typename NodeT::ValueOnCIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ValueOnCIter_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20nodet_2c_20typename_20nodet_3a_3avalueoniter_20_3e_97',['IterTraits&lt; NodeT, typename NodeT::ValueOnIter &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits_3_01NodeT_00_01typename_01NodeT_1_1ValueOnIter_01_4.html',1,'openvdb::v9_0::tree']]],
+  ['itertraits_3c_20typename_20previtert_3a_3anonconstnodetype_2c_20previtert_20_3e_98',['IterTraits&lt; typename PrevIterT::NonConstNodeType, PrevIterT &gt;',['../structopenvdb_1_1v9__0_1_1tree_1_1IterTraits.html',1,'openvdb::v9_0::tree']]]
 ];
